summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2018-11-28 12:41:39 +0100
committerJoas Schilling <coding@schilljs.com>2018-11-28 12:48:52 +0100
commit0106bd1e02fa2ccd6beffcbf78e78fceb246290d (patch)
treee2964f92716af1668587fdb1c3345861c158bf90
parent6cd02c8ede86ef2dc12dca7077c880ff7e56d05b (diff)
Use the new Namespace
Signed-off-by: Joas Schilling <coding@schilljs.com>
-rwxr-xr-xcompile-handlebars-templates.sh2
-rw-r--r--js/views/chatview.js8
-rw-r--r--js/views/richobjectstringparser.js8
-rw-r--r--js/views/templates.js2
4 files changed, 10 insertions, 10 deletions
diff --git a/compile-handlebars-templates.sh b/compile-handlebars-templates.sh
index 632488aff..8111f8555 100755
--- a/compile-handlebars-templates.sh
+++ b/compile-handlebars-templates.sh
@@ -5,4 +5,4 @@ export PATH=./node_modules/.bin/:$PATH
handlebars -n OCA.VideoCalls.Admin.Templates js/admin/templates/ -f js/admin/templates.js
-handlebars -n OCA.SpreedMe.Views.Templates js/views/templates/ -f js/views/templates.js
+handlebars -n OCA.Talk.Views.Templates js/views/templates/ -f js/views/templates.js
diff --git a/js/views/richobjectstringparser.js b/js/views/richobjectstringparser.js
index 7cc3be88b..02f7a25d1 100644
--- a/js/views/richobjectstringparser.js
+++ b/js/views/richobjectstringparser.js
@@ -49,7 +49,7 @@
switch (parameter.type) {
case 'user':
if (!this.userLocalTemplate) {
- this.userLocalTemplate = OCA.SpreedMe.Views.Templates['richobjectstringparser_userlocal'];
+ this.userLocalTemplate = OCA.Talk.Views.Templates['richobjectstringparser_userlocal'];
}
if (!parameter.name) {
parameter.name = parameter.id;
@@ -61,20 +61,20 @@
case 'file':
if (!this.filePreviewTemplate) {
- this.filePreviewTemplate = OCA.SpreedMe.Views.Templates['richobjectstringparser_filepreview'];
+ this.filePreviewTemplate = OCA.Talk.Views.Templates['richobjectstringparser_filepreview'];
}
return this.filePreviewTemplate(parameter);
default:
if (!_.isUndefined(parameter.link)) {
if (!this.unknownLinkTemplate) {
- this.unknownLinkTemplate = OCA.SpreedMe.Views.Templates['richobjectstringparser_unknownlink'];
+ this.unknownLinkTemplate = OCA.Talk.Views.Templates['richobjectstringparser_unknownlink'];
}
return this.unknownLinkTemplate(parameter);
}
if (!this.unknownTemplate) {
- this.unknownTemplate = OCA.SpreedMe.Views.Templates['richobjectstringparser_unknown'];
+ this.unknownTemplate = OCA.Talk.Views.Templates['richobjectstringparser_unknown'];
}
return this.unknownTemplate(parameter);
}
diff --git a/js/views/templates.js b/js/views/templates.js
index 7713d32b6..71fbccc0f 100644
--- a/js/views/templates.js
+++ b/js/views/templates.js
@@ -1,5 +1,5 @@
(function() {
- var template = Handlebars.template, templates = OCA.SpreedMe.Views.Templates = OCA.SpreedMe.Views.Templates || {};
+ var template = Handlebars.template, templates = OCA.Talk.Views.Templates = OCA.Talk.Views.Templates || {};
templates['chatview'] = template({"compiler":[7,">= 4.0.0"],"main":function(container,depth0,helpers,partials,data) {
var helper;
diff --git a/js/views/chatview.js b/js/views/chatview.js
index e1957c1a2..035225433 100644
--- a/js/views/chatview.js
+++ b/js/views/chatview.js
@@ -162,10 +162,10 @@
},
template: function(context) {
// OCA.SpreedMe.Views.Templates may not have been initialized when
// this view is initialized, so the template can not be directly
// assigned.
- return OCA.SpreedMe.Views.Templates['chatview'](context);
+ return OCA.Talk.Views.Templates['chatview'](context);
},
templateContext: {
emptyResultLabel: t('spreed', 'No messages yet, start the conversation!')
@@ -173,7 +173,7 @@
addCommentTemplate: function(params) {
if (!this._addCommentTemplate) {
- this._addCommentTemplate = OCA.SpreedMe.Views.Templates['chatview_add_comment'];
+ this._addCommentTemplate = OCA.Talk.Views.Templates['chatview_add_comment'];
}
return this._addCommentTemplate(_.extend({
@@ -187,7 +187,7 @@
commentTemplate: function(params) {
if (!this._commentTemplate) {
- this._commentTemplate = OCA.SpreedMe.Views.Templates['chatview_comment'];
+ this._commentTemplate = OCA.Talk.Views.Templates['chatview_comment'];
}
params = _.extend({
@@ -162,10 +162,10 @@
},
template: function(context) {
- // OCA.SpreedMe.Views.Templates may not have been initialized when
+ // OCA.Talk.Views.Templates may not have been initialized when
// this view is initialized, so the template can not be directly
// assigned.